==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/acl/lang/it/lang.php <==
<?php
/**
 * Italian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Giorgio Vecchiocattivi <giorgio@vecchio.it>
 * @author Roberto Bolli <http://www.rbnet.it/>
 * @author Pietro Battiston toobaz@email.it
 * @author Diego Pierotto ita.translations@tiscali.it
 */
$lang['admin_acl']             = 'Gestione Lista Controllo Accessi (ACL)';
$lang['acl_group']             = 'Gruppo';
$lang['acl_user']              = 'Utente';
$lang['acl_perms']             = 'Permessi per';
$lang['page']                  = 'Pagina';
$lang['namespace']             = 'Categoria';
$lang['p_user_id']             = 'L\'utente <b class="acluser">%s</b> attualmente ha i seguenti permessi sulla pagina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'L\'utente <b class="acluser">%s</b> attualmente ha i seguenti permessi per la categoria <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'I membri del gruppo<b class="aclgroup">%s</b> attualmente hanno i seguenti permessi sulla pagina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'I membri del gruppo<b class="aclgroup">%s</b> attualmente hanno i seguenti permessi per la categoria <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Per favore <b>inserisci un utente o gruppo</b> nel campo sopra per modificare i permessi impostati per la pagina <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Per favore <b>inserisci un utente o un gruppo</b> nel campo sopra per modificare i permessi impostati per la categoria <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Nota: Questi permessi non sono stati esplicitamente impostati, ma sono stati ereditati da altri gruppi o da categorie superiori.';
$lang['p_isadmin']             = 'Nota: Il gruppo o utente selezionato ha sempre tutti i permessi perché è configurato come amministratore.';
$lang['current']               = 'Regole ACL attuali';
$lang['where']                 = 'Pagina/Categoria';
$lang['who']                   = 'Utente/Gruppo';
$lang['perm']                  = 'Permessi';
$lang['acl_perm0']             = 'Nessuno';
$lang['acl_perm1']             = 'Lettura';
$lang['acl_perm2']             = 'Modifica';
$lang['acl_perm4']             = 'Creazione';
$lang['acl_perm8']             = 'Upload';
$lang['acl_perm16']            = 'Cancellazione';
$lang['acl_new']               = 'Aggiungi nuovo record';
$lang['acl_mod']               = 'Modifica record';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/it/lang.php <==
<?php
/**
 * Italian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Giorgio Vecchiocattivi <giorgio@vecchio.it>
 * @author Roberto Bolli <http://www.rbnet.it/>
 * @author Pietro Battiston toobaz@email.it
 * @author Diego Pierotto ita.translations@tiscali.it
 * @author ita.translations@tiscali.it
 * @author Lorenzo Breda <lbreda@gmail.com>
 */
$lang['admin_acl']             = 'Gestione Lista Controllo Accessi (ACL)';
$lang['acl_group']             = 'Gruppo';
$lang['acl_user']              = 'Utente';
$lang['acl_perms']             = 'Permessi per';
$lang['page']                  = 'Pagina';
$lang['namespace']             = 'Categoria';
$lang['btn_select']            = 'Seleziona';
$lang['p_user_id']             = 'L\'utente <b class="acluser">%s</b> attualmente ha i seguenti permessi sulla pagina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'L\'utente <b class="acluser">%s</b> attualmente ha i seguenti permessi per la categoria <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'I membri del gruppo<b class="aclgroup">%s</b> attualmente hanno i seguenti permessi sulla pagina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'I membri del gruppo<b class="aclgroup">%s</b> attualmente hanno i seguenti permessi per la categoria <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Per favore <b>inserisci un utente o gruppo</b> nel campo sopra per modificare i permessi impostati per la pagina <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Per favore <b>inserisci un utente o un gruppo</b> nel campo sopra per modificare i permessi impostati per la categoria <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Nota: Questi permessi non sono stati esplicitamente impostati, ma sono stati ereditati da altri gruppi o da categorie superiori.';
$lang['p_isadmin']             = 'Nota: Il gruppo o utente selezionato ha sempre tutti i permessi perché è configurato come amministratore.';
$lang['p_include']             = 'I permessi più elevati includono i permessi inferiori. I permessi di Creazione, Upload e Cancellazione si applicano soltanto alle categorie e non alle pagine.';
$lang['current']               = 'Regole ACL attuali';
$lang['where']                 = 'Pagina/Categoria';
$lang['who']                   = 'Utente/Gruppo';
$lang['perm']                  = 'Permessi';
$lang['acl_perm0']             = 'Nessuno';
$lang['acl_perm1']             = 'Lettura';
$lang['acl_perm2']             = 'Modifica';
$lang['acl_perm4']             = 'Creazione';
$lang['acl_perm8']             = 'Upload';
$lang['acl_perm16']            = 'Cancellazione';
$lang['acl_new']               = 'Aggiungi nuovo record';
$lang['acl_mod']               = 'Modifica record';
